@@ -1,5 +1,5 @@
 /*
- *  $Id: build_ip.c,v 1.3 1998/12/08 19:34:49 route Exp $
+ *  $Id: build_ip.c,v 1.5 1999/01/28 03:01:58 route Exp $
  *
  *  libnet
  *  build_ip.c - Crude IP packet assembler.
@@ -37,23 +37,29 @@ build_ip(u_short len, u_char tos, u_short id, u_short frag, u_char ttl,
         u_char prot, u_long src, u_long dst, const u_char *payload,
         int payload_s, u_char *buf)
 {
-    struct ip *ip_hdr;
+    struct ip ip_hdr;
 
     assert(buf);
-    ip_hdr = (struct ip *)(buf);
-
-    ip_hdr->ip_v    = 4;                            /* version 4 */
-    ip_hdr->ip_hl   = 5;                            /* 20 byte header */
-    ip_hdr->ip_tos  = tos;                          /* IP tos */
-    ip_hdr->ip_len  = htons(IP_H + len + payload_s);/* total length */
-    ip_hdr->ip_id   = htons(id);                    /* IP ID */
-    ip_hdr->ip_off  = htons(frag);                  /* fragmentation flags */
-    ip_hdr->ip_ttl  = ttl;                          /* time to live */
-    ip_hdr->ip_p    = prot;                         /* transport protocol */
-    ip_hdr->ip_sum  = 0;                            /* do this later */
-    ip_hdr->ip_src.s_addr = src;                    /* source address */
-    ip_hdr->ip_dst.s_addr = dst;                    /* destination address */
 
+    ip_hdr.ip_v    = 4;                            /* version 4 */
+    ip_hdr.ip_hl   = 5;                            /* 20 byte header */
+    ip_hdr.ip_tos  = tos;                          /* IP tos */
+    ip_hdr.ip_len  = htons(IP_H + len + payload_s);/* total length */
+    ip_hdr.ip_id   = htons(id);                    /* IP ID */
+    ip_hdr.ip_off  = htons(frag);                  /* fragmentation flags */
+    ip_hdr.ip_ttl  = ttl;                          /* time to live */
+    ip_hdr.ip_p    = prot;                         /* transport protocol */
+    ip_hdr.ip_sum  = 0;                            /* do this later */
+#if (LBL_ALIGN)
+    /*
+     *  Alignment problems.
+     */
+    memcpy((char *)&ip_hdr.ip_src.s_addr, (char *)&src, 4);
+    memcpy((char *)&ip_hdr.ip_dst.s_addr, (char *)&dst, 4);
+#else
+    ip_hdr.ip_src.s_addr = src;
+    ip_hdr.ip_dst.s_addr = dst;
+#endif
     if (payload && payload_s)
     {
         /*
@@ -62,6 +68,7 @@ build_ip(u_short len, u_char tos, u_short id, u_short frag, u_char ttl,
          */
         memcpy(buf + IP_H, payload, payload_s);
     }
+    memcpy(buf, &ip_hdr, sizeof(ip_hdr));
 }
 
 
