@@ -1,5 +1,5 @@
 /*
- *  $Id: resolve.c,v 1.1.1.1 1998/11/27 06:04:10 route Exp $
+ *  $Id: resolve.c,v 1.5 1999/01/31 21:05:41 route Exp $
  *
  *  libnet
  *  resolve.c - Various name resolution type routines
@@ -46,7 +46,7 @@ host_lookup(u_long in, u_short use_name)
      *  Swap to the other buffer.  We swap static buffers to avoid having to
      *  pass in a char *.  This makes the code that calls this function more
      *  intuitive, but makes this function ugly.  This function is seriously
-     *  non-rentrant.  For threaded applications (or for signal handler code)
+     *  non-reentrant.  For threaded applications (or for signal handler code)
      *  use host_lookup_r().
      */
     which++;
@@ -147,4 +147,72 @@ name_resolve(u_char *host_name, u_short use_name)
 }
 
 
+/*
+ *  libpcap provides a way to get net and mask, but not this.
+ *  Derrick J Brashear <shadow@dementia.org>
+ */
+u_long
+get_ipaddr(struct link_int *l, const u_char *device, char *ebuf)
+{
+    struct ifreq ifr;
+    register struct sockaddr_in *sin;
+    int fd;
+
+    /*
+     *  Create dummy socket to perform an ioctl upon.
+     */
+    fd = socket(PF_INET, SOCK_DGRAM, 0);
+    if (fd < 0)
+    {
+        sprintf(ebuf, "socket: %s", strerror(errno));
+        return (0);
+    }
+
+    memset(&ifr, 0, sizeof(ifr));
+    sin = (struct sockaddr_in *)&ifr.ifr_addr;
+    strncpy(ifr.ifr_name, device, sizeof(ifr.ifr_name));
+
+    if (ioctl(fd, SIOCGIFADDR, (char*) &ifr) < 0)
+    {
+        close(fd);
+        return(0);
+    }
+    close(fd);
+    return (ntohl(sin->sin_addr.s_addr));
+}
+
+
+#if !(HAVE_DLPI) && !(__linux__)
+struct ether_addr *
+get_hwaddr(struct link_int *l, const u_char *device, char *ebuf)
+{
+    struct ifreq ifr;
+    int fd;
+    struct ether_addr *eap;
+
+    /*
+     *  Create dummy socket to perform an ioctl upon.
+     */
+    fd = socket(PF_INET, SOCK_DGRAM, 0);
+    if (fd < 0)
+    {
+        sprintf(ebuf, "socket: %s", strerror(errno));
+        return (0);
+    }
+
+    memset(&ifr, 0, sizeof(ifr));
+    eap = (struct ether_addr *) &ifr.ifr_addr;
+    strncpy(ifr.ifr_name, device, sizeof(ifr.ifr_name));
+
+    if (ioctl(fd, SIOCGIFADDR, (char*) &ifr) < 0)
+    {
+        close(fd);
+        return (0);
+    }
+    close(fd);
+    return (eap);
+}
+#endif
+
+
 /* EOF */
