@@ -1,5 +1,5 @@
 /*
- *  $Id: socket.c,v 1.1.1.1 1998/11/27 06:04:10 route Exp $
+ *  $Id: socket.c,v 1.2 1999/01/31 21:05:41 route Exp $
  *
  *  libnet
  *  socket.c - Opens a raw socket of type `prot` and sets the IP_HDRINCL
@@ -47,12 +47,18 @@ open_raw_sock(prot)
     fd = socket(AF_INET, SOCK_RAW, prot);
     if (fd == -1)
     {
-        DEBUG("open_raw_sock: SOCK_RAW allocation: %s\n", strerror(errno));
+#if (__DEBUG)
+        fprintf(stderr, "open_raw_sock: SOCK_RAW allocation: %s\n",
+            strerror(errno));
+#endif
         return (-1);
     }
     if (setsockopt(fd, IPPROTO_IP, IP_HDRINCL, oneptr, sizeof(one)) == -1)
     {
-        DEBUG("open_raw_sock: setting IP_HDRINCL: %s\n", strerror(errno));
+#if (__DEBUG)
+        fprintf(stderr, "open_raw_sock: setting IP_HDRINCL: %s\n",
+            strerror(errno));
+#endif
         return (-1);
     }
     return (fd);
